===========
Admonitions
===========

Translator render from admonitions directives to message components.

Simple usage
============

.. attention:: This is an attention

.. caution:: What's happen!!

.. danger:: It is dangerous zone

.. error:: Error is occured.

.. hint:: A little hint

.. important:: Important announce

.. note:: Show note

.. tip:: Tip for customize

.. warning:: It is deprecated.

.. todo:: Suppored Sphinx's Todo directive.

Complex usage
=============

.. note::

   This is example of paragraph-style note.

   You can render complex contents in admonitions.

   * Multi-line paragraph.
   * Listed content
